@@ -549,7 +549,7 @@ QPixmap Area::cutOut(const QImage & image)
 //  partOfMask = partOfMask.normalize();
 	if (!partOfMask.isValid())
 	   qCDebug(KIMAGEMAPEDITOR_LOG) << "PartofMask not valid : " << partOfMask.x() << "," << partOfMask.y() << ","
-	            << partOfMask.width() << "," << partOfMask.height() << "," << endl;
+                << partOfMask.width() << "," << partOfMask.height() << ",";
 
 /*
 	QBitmap mask2(partOfMask.width(), partOfMask.height());
@@ -733,7 +733,7 @@ bool RectArea::setCoords(const QString & s)
 {
 	_finished=true;
 
-	const QStringList list = s.split(",");
+	const QStringList list = s.split(',');
 	QRect r;
  	bool ok=true;
  	QStringList::ConstIterator it = list.begin();
@@ -913,7 +913,7 @@ void CircleArea::updateSelectionPoints()
 bool CircleArea::setCoords(const QString & s)
 {
 	_finished=true;
-	const QStringList list = s.split(",");
+	const QStringList list = s.split(',');
  	bool ok=true;
  	QStringList::ConstIterator it = list.begin();
  	int x=(*it).toInt(&ok,10);it++;
@@ -1158,7 +1158,7 @@ void PolyArea::updateSelectionPoints()
 bool PolyArea::setCoords(const QString & s)
 {
 	_finished=true;
-	const QStringList list = s.split(",");
+	const QStringList list = s.split(',');
 	_coords.clear();
 	_selectionPoints.clear();
 
